
OptionsViewModel = class(ViewModelBase);

-- Initialize a new OptionsViewModel instance
function OptionsViewModel:Constructor(filterEngine)
	ViewModelBase.Constructor(self);

	-- private
	self.Engine = filterEngine;
	
	-- public
	self.Debug = self.Engine:IsDebugEnabled();
	self.Trace = self.Engine:IsTraceSpamEnabled();
	self.FilterState = self.Engine:IsActive();
	self.PolicyState = {};

	for k, v in pairs(self.Engine.Data.Policies) do
		self.PolicyState[k] = v;
	end
	
	self._windows = {};

	local openWindow = function(window)
		self._windows[window] = window;

		local function windowClosed(sender, args)
			Events.RemoveCallback(sender, "Closed", windowClosed);
			self._windows[sender] = nil;
		end

		Events.AddCallback(window, "Closed", windowClosed);

		window:CenterWindow();
		window:SetVisible(true);
	end

	self.MonitorCommand = function()
		openWindow(Views.MonitorWindow(MonitorViewModel(self.Engine)));
	end;
	
	self.SpamPolicyCommand = function()
		openWindow(Views.SpamPolicyWindow(SpamViewModel(self.Engine)));
	end;
	
	self.BlacklistPolicyCommand = function()
		openWindow(Views.BlacklistPolicyWindow(BlacklistViewModel(self.Engine)));
	end;
	
	self.GoldsellerPolicyCommand = function()
		openWindow(Views.GoldsellerPolicyWindow(GoldsellerViewModel(self.Engine)));
	end;
	
	self.HelpCommand = function()
		openWindow(Views.HelpWindow(HelpViewModel()));
	end;

	self:AddCallback(self.Engine, "DebugChanged", function(sender, enabled)
		self:SetProperty("Debug", enabled);
	end);

	self:AddCallback(self.Engine, "TraceSpamChanged", function(sender, enabled)
		self:SetProperty("Trace", enabled);
	end);

	self:AddCallback(self.Engine, "ActiveChanged", function(sender, enabled)
		self:SetProperty("FilterState", enabled);
	end);

	self:AddCallback(self.Engine, "PolicyStateChanged", function(sender, args)
		if self.PolicyState[args.Name] ~= args.Value then
			self.PolicyState[args.Name] = args.Value;
			self:RaisePropertyChanged("PolicyState");
		end
	end);
end

-- public
function OptionsViewModel:SetDebug(enabled)
	self.Engine:SetDebug(enabled);
end

-- public
function OptionsViewModel:SetTrace(enabled)
	self.Engine:SetTraceSpam(enabled);
end

-- public
function OptionsViewModel:SetFilterState(enabled)
	self.Engine:SetActive(enabled);
end

-- public
function OptionsViewModel:SetPolicy(policyName, enabled)
	self.Engine:SetPolicyEnabled(policyName, enabled);
end
