
OptionsPanel = class(LayoutBase);

-- Initializes a new OptionsPanel instance
function OptionsPanel:Constructor(viewModel)
	LayoutBase.Constructor(self);
	self.ViewModel = viewModel;
	self:Initialize();
end

function OptionsPanel:Initialize()
	-- set global styles
	ButtonStyle.BorderWidth = 1;
	ButtonStyle.Font = Turbine.UI.Lotro.Font.TrajanPro14;
	ButtonStyle.ForeColor = Turbine.UI.Color(0.7, 0.7, 0.2);
	ButtonStyle.Image = Images.Button;
	ButtonStyle.ImageMode = ImageMode.RepeatImage;
	ButtonStyle.FontStyle = Turbine.UI.FontStyle.Outline;
	ButtonStyle.MouseDownColor = Turbine.UI.Color(0.98, 0.3, 0.3, 0.3);
	ButtonStyle.MouseEnterColor = Turbine.UI.Color(0.98, 0.7, 0.7, 1);
	ButtonStyle.MouseLeaveColor = Turbine.UI.Color(0.98, 0.4, 0.4, 0.4);

	local bindings = {
		["IsDebug"] = self.ViewModel.Debug,
		["DebugCheckedChanged"] = function(sender, args)
			self.ViewModel:SetDebug(sender:IsChecked());
		end,

		["IsTraceSpam"] = self.ViewModel.Trace,
		["TraceSpamCheckedChanged"] = function(sender, args)
			self.ViewModel:SetTrace(sender:IsChecked());
		end,

		["IsActive"] = self.ViewModel.FilterState,
		["ActiveCheckedChanged"] = function(sender, args)
			self.ViewModel:SetFilterState(sender:IsChecked());
		end,

		["MonitorButtonClick"] = self.ViewModel.MonitorCommand,
		["SpamPolicyButtonClick"] = self.ViewModel.SpamPolicyCommand,
		["BlacklistPolicyButtonClick"] = self.ViewModel.BlacklistPolicyCommand,
		["GoldsellerPolicyButtonClick"] = self.ViewModel.GoldsellerPolicyCommand,
		["HelpButtonClick"] = self.ViewModel.HelpCommand,
	};

	-- content
	local content = TemplateLoader.Setup(self, self:GetTemplate(bindings));
	content:SetParent(self);
	
	-- add policies
	for k, v in pairs(self.ViewModel.PolicyState) do
		local item;
		local bindings;

		bindings = {
			["CheckBoxName"] = k,
			["Title"] = k,
			["Checked"] = v,
			["CheckedChanged"] = function(sender, args)
				self.ViewModel:SetPolicy(k, sender:IsChecked());
			end,
		};

		item = TemplateLoader.Setup(self, self:GetPolicyItemTemplate(bindings));

		local control = self.PoliciesPanel:AddControl(item);
		control.ContentStyle:SetPadding(4);
	end

	self.ViewModel:OnPropertyChanged("Debug", function(sender)
		self.DebugCheckBox:SetChecked(sender.Debug);
	end);
	
	self.ViewModel:OnPropertyChanged("Trace", function(sender)
		self.TraceSpamCheckBox:SetChecked(sender.Trace);
	end);
	
	self.ViewModel:OnPropertyChanged("FilterState", function(sender)
		self.ActiveCheckBox:SetChecked(sender.FilterState);
	end);

	self.ViewModel:OnPropertyChanged("PolicyState", function(sender)
		-- see add policies
		for k, v in pairs(self.ViewModel.PolicyState) do
			if self[k] ~= nil then
				self[k]:SetChecked(v);
			end
		end
	end);
end

function OptionsPanel:SizeChanged(args)
	LayoutBase.SizeChanged(self, args);
	self:PerformLayout();
end

function OptionsPanel:Layout()
	self.Content:SetSize(self:GetSize());
	self.Content:PerformLayout();
	self:SetSize(self.Content:GetSize());
	--self:PerformLayout();
end

function OptionsPanel:GetTemplate(bindings)
	return {
		["Type"] = Border,
		["Name"] = "Content",
		["BorderWidth"] = 10,
		["BorderColor"] = Turbine.UI.Color(0.9, 0.0, 0.0, 0.0),
		["Content"] = 
		{
			{
				["Type"] = StackPanel,
				["Content"] =
				{
					{
						["Type"] = Image,
						["Height"] = 150,
						["ImageMode"] = ImageMode.KeepImage,
						["Background"] = Images.Headline,
						["BlendMode"] = Turbine.UI.BlendMode.Overlay,
						["HorizontalAlignment"] = HorizontalAlignment.Center,
						["VerticalAlignment"] = VerticalAlignment.Center,
					},
					{
						["Type"] = TextBlock,
						["Text"] = Strings.CommonSettings,
						["TextAlignment"] = Turbine.UI.ContentAlignment.MiddleLeft,
						["Content.VerticalAlignment"] = VerticalAlignment.Bottom,
						["Content.PaddingTop"] = 10,
						
					},
					{
						["Type"] = Border,
						["BorderWidth"] = 1,
						["Content"] =
						{
							{
								["Type"] = StackPanel,
								["Content.Padding"] = 4,
								["Content"] =
								{
									{
										["Type"] = CheckBox,
										["Name"] = "ActiveCheckBox",
										["Text"] = Strings.FilterActivate,
										["Checked"] = bindings["IsActive"],
										["CheckedChanged"] = bindings["ActiveCheckedChanged"],
										["Content.Padding"] = 4,
									},
									{
										["Type"] = CheckBox,
										["Name"] = "TraceSpamCheckBox",
										["Text"] = Strings.TraceActivate,
										["Checked"] = bindings["IsTraceSpam"],
										["CheckedChanged"] = bindings["TraceSpamCheckedChanged"],
										["Content.Padding"] = 4,
									},
									{
										["Type"] = CheckBox,
										["Name"] = "DebugCheckBox",
										["Text"] = "Debug",
										["Checked"] = bindings["IsDebug"],
										["CheckedChanged"] = bindings["DebugCheckedChanged"],
										["Content.Padding"] = 4,
									},
								},
							},
						},
					},
					{
						["Type"] = TextBlock,
						["Text"] = Strings.Policies,
						["TextAlignment"] = Turbine.UI.ContentAlignment.MiddleLeft,
						["Content.VerticalAlignment"] = VerticalAlignment.Bottom,
						["Content.PaddingTop"] = 10,
						
					},
					{
						["Type"] = Border,
						["BorderWidth"] = 1,
						["Content"] =
						{
							{
								["Type"] = StackPanel,
								["Name"] = "PoliciesPanel",
								["Content.Padding"] = 4,
								["Content"] =
								{
								},
							},
						},
					},
					{
						["Type"] = FlowPanel,
						["Content.PaddingTop"] = 10,
						["Content"] =
						{
							{
								["Type"] = Button,
								["Text"] = "Monitor",
								["Content.MaxWidth"] = 150,
								["Content.PaddingRight"] = 4,
								["Content.PaddingBottom"] = 4,
								["Click"] = bindings["MonitorButtonClick"],
							},
							{
								["Type"] = Button,
								["Text"] = "Spam Policy",
								["Content.MaxWidth"] = 150,
								["Content.PaddingRight"] = 4,
								["Content.PaddingBottom"] = 4,
								["Click"] = bindings["SpamPolicyButtonClick"],
							},
							{
								["Type"] = Button,
								["Text"] = "Blacklist Policy",
								["Content.MaxWidth"] = 150,
								["Content.PaddingRight"] = 4,
								["Content.PaddingBottom"] = 4,
								["Click"] = bindings["BlacklistPolicyButtonClick"],
							},
							{
								["Type"] = Button,
								["Text"] = "Goldseller Policy",
								["Content.MaxWidth"] = 150,
								["Content.PaddingRight"] = 4,
								["Content.PaddingBottom"] = 4,
								["Click"] = bindings["GoldsellerPolicyButtonClick"],
							},
							{
								["Type"] = Button,
								["Text"] = Strings.Help,
								["Content.MaxWidth"] = 150,
								["Content.PaddingRight"] = 4,
								["Content.PaddingBottom"] = 4,
								["Click"] = bindings["HelpButtonClick"],
							},
						},
					},
				},
			},
		},
	};
end

function OptionsPanel:GetPolicyItemTemplate(bindings)
	return {
		["Type"] = CheckBox,
		["Name"] = bindings["CheckBoxName"],
		["Text"] = bindings["Title"],
		["Checked"] = bindings["Checked"],
		["CheckedChanged"] = bindings["CheckedChanged"],
	};
end
